==> ajaxplorer-4.2.3.tbz: www/ajaxplorer/plugins/notify.phpmail-lite/i18n/conf/en.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"Simple Notification" => "Simple Notification",
"Notification system (demonstrative)" => "Notification system (demonstrative)",
"Sender" => "Sender",
"Name and adress of the sender, use Name:mail_address format." => "Name and adress of the sender, use Name:mail_address format.",
"Recipient(s)" => "Recipient(s)",
"Comma separated list of permanent recipients, e.g Name1:address1,Name2:address2, etc. Leave empty if you want only the share feature." => "Comma separated list of permanent recipients, e.g Name1:address1,Name2:address2, etc. Leave empty if you want only the share feature.",
"Enrich Shares" => "Enrich Shares",
"Add a notification pane to the share mechanism, proposing the user to enter her email to be notified when the shared repository is modified" => "Add a notification pane to the share mechanism, proposing the user to enter her email to be notified when the shared repository is modified",
"Notify on..." => "Notify on...",
"Comma-separated list of action on wich the notification should be sent" => "Comma-separated list of action on wich the notification should be sent",
"Subject" => "Subject",
"Subject to be displayed in the mail" => "Subject to be displayed in the mail",
"Body" => "Body",
"Body of the email. You can use AJXP_USER, AJXP_FILE, AJXP_FOLDER and AJXP_ACTION keywords." => "Body of the email. You can use AJXP_USER, AJXP_FILE, AJXP_FOLDER and AJXP_ACTION keywords.",
"Mailer" => "Mailer",
"Php mailer to use (see phpmail-lite documentation).'." => "Php mailer to use (see phpmail-lite documentation).'.",
);
?>

==> ajaxplorer-5.0.1.tbz: www/ajaxplorer/plugins/notify.phpmail-lite/i18n/conf/en.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"Simple Notification" => "Simple Notification",
"Notification system (demonstrative)" => "Notification system (demonstrative)",
"Sender" => "Sender",
"Name and adress of the sender, use Name:mail_address format." => "Name and adress of the sender, use Name:mail_address format.",
"Recipient(s)" => "Recipient(s)",
"Comma separated list of permanent recipients, e.g Name1:address1,Name2:address2, etc. Leave empty if you want only the share feature." => "Comma separated list of permanent recipients, e.g Name1:address1,Name2:address2, etc. Leave empty if you want only the share feature.",
"Enrich Shares" => "Enrich Shares",
"Add a notification pane to the share mechanism, proposing the user to enter her email to be notified when the shared repository is modified" => "Add a notification pane to the share mechanism, proposing the user to enter her email to be notified when the shared workspace is modified",
"Notify on..." => "Notify on...",
"Comma-separated list of action on wich the notification should be sent" => "Comma-separated list of action on wich the notification should be sent",
"Subject" => "Subject",
"Subject to be displayed in the mail" => "Subject to be displayed in the mail",
"Body" => "Body",
"Body of the email. You can use AJXP_USER, AJXP_FILE, AJXP_FOLDER and AJXP_ACTION keywords." => "Body of the email. You can use AJXP_USER, AJXP_FILE, AJXP_FOLDER and AJXP_ACTION keywords.",
"Mailer" => "Mailer",
"Php mailer to use (see phpmail-lite documentation).'." => "Php mailer to use (see phpmail-lite documentation).'.",
);
?>
